==> flutter_firebase_basic_tools-0.0.20.tar.gz: lib/widgets/class_quiz_question.dart <==
import 'package:flutter_firebase_basic_tools/widgets/class_quiz_answer_item.dart';
import 'package:flutter_firebase_basic_tools/logic/translate.dart';
import 'package:auto_size_text/auto_size_text.dart';
import 'package:flutter/material.dart';
import 'package:shared_preferences/shared_preferences.dart';

class ClassQuizQuestion extends StatefulWidget {
  const ClassQuizQuestion({
    this.questionTitle,
    this.answers,
    this.demos,
    this.classQuiz,
    this.correctAnswer,
    this.questionID,
    @required this.apiKey,
  });

  final String questionTitle;
  final List answers;
  final List demos;
  final classQuiz;
  final String correctAnswer;
  final int questionID;
  final String apiKey;

  @override
  _ClassQuizQuestionState createState() => _ClassQuizQuestionState();
}

class _ClassQuizQuestionState extends State<ClassQuizQuestion> {
  int currentIndex = -1;

  List<bool> answersSelected = List<bool>();

  bool demosIsNull = false;

  TranslationStream translationStream = TranslationStream();

  List<String> textList = [
    "Lives:",
    "Validate",
    "Progress:",
  ];

  getQuizData() {
    for (var i = 0; i < widget.answers.length; i++) {
      answersSelected.add(false);
    }

    widget.answers.shuffle();

    if (widget.demos == null) {
      demosIsNull = true;
    }

    setState(() {});
  }

  SharedPreferences prefs;
  String currentLanguage = "en";

  initSharedPreferences() async {
    prefs = await SharedPreferences.getInstance();

    if (prefs.getString("language_target") != null) {
      currentLanguage = prefs.getString("language_target");
    }

    textList = [
      widget.questionTitle,
      "Validate",
      widget.correctAnswer,
    ];

    for (int i = 0; i < widget.answers.length; i++) {
      textList.add(widget.answers[i].toString());
    }

    setState(() {});

    translationStream.init(textList, this);
    translationStream.translate(widget.apiKey);

    getQuizData();
  }

  @override
  void initState() {
    super.initState();
    initSharedPreferences();
  }

  @override
  Widget build(BuildContext context) {
    bool isPortrait =
        MediaQuery.of(context).orientation == Orientation.portrait;

    return Container(
      child: Column(
        children: <Widget>[
          Spacer(flex: 1),
          Expanded(
            flex: 3,
            child: Container(
              width: isPortrait ? 300 : 700,
              child: AutoSizeText(
                textList[0],
                textAlign: TextAlign.left,
                style: TextStyle(
                  color: Colors.black,
                  fontSize: 16,
                  fontWeight: FontWeight.bold,
                ),
                minFontSize: 12,
                maxLines: 5,
                overflow: TextOverflow.clip,
              ),
            ),
          ),
          demosIsNull
              ? Container()
              : Expanded(
                  flex: 3,
                  child: Image.network(
                    widget.demos[0],
                    fit: BoxFit.fitHeight,
                  ),
                ),
          Expanded(
            flex: 10,
            child: Container(
              child: ListView.builder(
                shrinkWrap: true,
                itemCount: widget.answers.length,
                itemBuilder: (BuildContext context, int index) =>
                    FractionallySizedBox(
                  widthFactor: isPortrait ? 0.8 : 0.65,
                  child: ClassQuizAnswerItem(
                    answerText: textList[index + 3] != null ? textList[index + 3] : "",
                    index: index,
                    classQuizQuestion: this,
                    isSelected: currentIndex == index,
                    backgroundColor: widget.answers.length > 2
                        ? (index % 2 == 0) ? Colors.white : Color(0xffe4eded)
                        : Colors.white,
                  ),
                ),
              ),

              /*Column(
                children: List.generate(widget.answers.length, (index) {
                  return ClassQuizAnswerItem(
                    answerText: widget.answers[index].toString(),
                    index: index,
                    classQuizQuestion: this,
                    isSelected: currentIndex == index,
                  );
                }),
              ),*/
            ),
          ),
          Spacer(flex: 1),
          RaisedButton(
            onPressed: () {
              bool answerIscorrect = (textList[currentIndex + 3] != null ? textList[currentIndex + 3] : "")  == textList[2];

              print("answerIscorrect: " + answerIscorrect.toString());

              widget.classQuiz
                  .getNextQuestion(answerIscorrect, widget.questionID);
            },
            child: Text(textList[1]),
          ),
          Spacer(flex: 1),
        ],
      ),
    );
  }
}

==> flutter_firebase_basic_tools-0.0.70.tar.gz: lib/widgets/class_quiz_question.dart <==
import 'package:flutter_firebase_basic_tools/widgets/class_quiz_answer_item.dart';
import 'package:flutter_firebase_basic_tools/logic/translate.dart';
import 'package:auto_size_text/auto_size_text.dart';
import 'package:flutter/material.dart';
import 'package:shared_preferences/shared_preferences.dart';

class ClassQuizQuestion extends StatefulWidget {
  const ClassQuizQuestion({
    this.questionTitle,
    this.answers,
    this.demos,
    this.classQuiz,
    this.correctAnswer,
    this.questionID,
    @required this.apiKey,
  });

  final String questionTitle;
  final List answers;
  final List demos;
  final classQuiz;
  final String correctAnswer;
  final int questionID;
  final String apiKey;

  @override
  _ClassQuizQuestionState createState() => _ClassQuizQuestionState();
}

class _ClassQuizQuestionState extends State<ClassQuizQuestion> {
  int currentIndex = -1;

  List<bool> answersSelected = List<bool>();

  bool demosIsNull = false;

  TranslationStream translationStream = TranslationStream();

  List<String> textList = [
    "Lives:",
    "Validate",
    "Progress:",
  ];

  getQuizData() {
    for (var i = 0; i < widget.answers.length; i++) {
      answersSelected.add(false);
    }

    widget.answers.shuffle();

    if (widget.demos == null) {
      demosIsNull = true;
    }

    setState(() {});
  }

  SharedPreferences prefs;
  String currentLanguage = "en";

  initSharedPreferences() async {
    prefs = await SharedPreferences.getInstance();

    if (prefs.getString("language_target") != null) {
      currentLanguage = prefs.getString("language_target");
    }

    textList = [
      widget.questionTitle,
      "Validate",
      widget.correctAnswer,
    ];

    for (int i = 0; i < widget.answers.length; i++) {
      textList.add(widget.answers[i].toString());
    }

    setState(() {});

    translationStream.init(textList, updateTextList);
    translationStream.translate(widget.apiKey);

    getQuizData();
  }

  updateTextList(int index, String newText){
    textList[index] = newText;
    setState(() {});
  }

  @override
  void initState() {
    super.initState();
    initSharedPreferences();
  }

  @override
  Widget build(BuildContext context) {
    bool isPortrait =
        MediaQuery.of(context).orientation == Orientation.portrait;

    return Container(
      child: Column(
        children: <Widget>[
          Spacer(flex: 1),
          Expanded(
            flex: 3,
            child: Container(
              width: isPortrait ? 300 : 700,
              child: AutoSizeText(
                textList[0],
                textAlign: TextAlign.left,
                style: TextStyle(
                  color: Colors.black,
                  fontSize: 16,
                  fontWeight: FontWeight.bold,
                ),
                minFontSize: 12,
                maxLines: 5,
                overflow: TextOverflow.clip,
              ),
            ),
          ),
          demosIsNull
              ? Container()
              : Expanded(
                  flex: 3,
                  child: Image.network(
                    widget.demos[0],
                    fit: BoxFit.fitHeight,
                  ),
                ),
          Expanded(
            flex: 10,
            child: Container(
              child: ListView.builder(
                shrinkWrap: true,
                itemCount: widget.answers.length,
                itemBuilder: (BuildContext context, int index) =>
                    FractionallySizedBox(
                  widthFactor: isPortrait ? 0.8 : 0.65,
                  child: ClassQuizAnswerItem(
                    answerText: textList[index + 3] != null ? textList[index + 3] : "",
                    index: index,
                    classQuizQuestion: this,
                    isSelected: currentIndex == index,
                    backgroundColor: widget.answers.length > 2
                        ? (index % 2 == 0) ? Colors.white : Color(0xffe4eded)
                        : Colors.white,
                  ),
                ),
              ),

              /*Column(
                children: List.generate(widget.answers.length, (index) {
                  return ClassQuizAnswerItem(
                    answerText: widget.answers[index].toString(),
                    index: index,
                    classQuizQuestion: this,
                    isSelected: currentIndex == index,
                  );
                }),
              ),*/
            ),
          ),
          Spacer(flex: 1),
          RaisedButton(
            onPressed: () {
              bool answerIscorrect = (textList[currentIndex + 3] != null ? textList[currentIndex + 3] : "")  == textList[2];

              print("answerIscorrect: " + answerIscorrect.toString());

              widget.classQuiz
                  .getNextQuestion(answerIscorrect, widget.questionID);
            },
            child: Text(textList[1]),
          ),
          Spacer(flex: 1),
        ],
      ),
    );
  }
}
